@@ -127,10 +127,10 @@
 
 #define SUN_BUILD_TYPE "RelWithDebInfo"
 
-#define SUN_JOB_ID "20250930005546"
-#define SUN_JOB_START_TIME "20250930005546"
+#define SUN_JOB_ID "20251028015543"
+#define SUN_JOB_START_TIME "20251028015543"
 
-#define SUN_TPL_LIST "MPI;OPENMP;KLU;PTHREAD"
+#define SUN_TPL_LIST "MPI;OPENMP;KLU;BLAS_LAPACK;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
 
 #define SUNDIALS_SPACK_VERSION ""
@@ -169,7 +169,7 @@
 #define SUN_KOKKOS_KERNELS_VERSION ""
 
 /* LAPACK */
-/* #undef SUNDIALS_BLAS_LAPACK_ENABLED */
+#define SUNDIALS_BLAS_LAPACK_ENABLED
 #define SUN_LAPACK_VERSION ""
 
 /* MAGMA */
@@ -305,6 +305,8 @@
 #define SUNDIALS_SUNLINSOL_SPGMR 1
 #define SUNDIALS_SUNLINSOL_SPTFQMR 1
 #define SUNDIALS_SUNLINSOL_KLU 1
+#define SUNDIALS_SUNLINSOL_LAPACKBAND 1
+#define SUNDIALS_SUNLINSOL_LAPACKDENSE 1
 #define SUNDIALS_SUNNONLINSOL_NEWTON 1
 #define SUNDIALS_SUNNONLINSOL_FIXEDPOINT 1
 
